## dbt-adapters 1.20.1 - November 21, 2025

### Fixes

- safe comparison of Recorder.record_row_limit ([#1461](https://github.com/dbt-labs/dbt-adapters/issues/1461))
- Fix serializing recorded agate tables and column schemas ([#1462](https://github.com/dbt-labs/dbt-adapters/issues/1462))
